You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by st...@apache.org on 2013/09/28 00:22:10 UTC

svn commit: r1527105 - /subversion/trunk/subversion/libsvn_subr/cache_config.c

Author: stefan2
Date: Fri Sep 27 22:22:10 2013
New Revision: 1527105

URL: http://svn.apache.org/r1527105
Log:
Follow-up to r1527103: fix a "shadow identifier" compiler warning.

* subversion/libsvn_subr/cache_config.c
  (svn_cache_config_get): rename POOL parameter

Modified:
    subversion/trunk/subversion/libsvn_subr/cache_config.c

Modified: subversion/trunk/subversion/libsvn_subr/cache_config.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_subr/cache_config.c?rev=1527105&r1=1527104&r2=1527105&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_subr/cache_config.c (original)
+++ subversion/trunk/subversion/libsvn_subr/cache_config.c Fri Sep 27 22:22:10 2013
@@ -72,10 +72,10 @@ svn_cache_config_get(void)
 
 /* Initializer function as required by svn_atomic__init_once.  Allocate
  * the process-global (singleton) membuffer cache and return it in the
  * svn_membuffer_t * in *BATON.  POOL is unused and should be NULL.
  */
 static svn_error_t *
-initialize_cache(void *baton, apr_pool_t *pool)
+initialize_cache(void *baton, apr_pool_t *unused_pool)
 {
   svn_membuffer_t **cache_p = baton;
   svn_membuffer_t *cache = NULL;
@@ -72,10 +72,10 @@ svn_cache_config_get(void)
 /* Initializer function as required by svn_atomic__init_once.  Allocate
  * the process-global (singleton) membuffer cache and return it in the
- * svn_membuffer_t * in *BATON.  POOL is unused and should be NULL.
+ * svn_membuffer_t * in *BATON.  UNUSED_POOL is unused and should be NULL.
  */
 static svn_error_t *